@@ -1,13 +1,16 @@
+# -*- coding: utf-8 -*-
 import unittest, aipy._alm as a, numpy as n
 
 class TestAlm(unittest.TestCase):
     def test_init(self):
+        """Test initializing a aipy._alm object"""
         alm = a.Alm(10, 5)
         self.assertEqual(alm.lmax(), 10)
         self.assertEqual(alm.mmax(), 5)
         self.assertRaises(RuntimeError, a.Alm, 5, 10)
 
-class TestMemLeaks(unittest.TestCase):
+if False:
+  class TestMemLeaks(unittest.TestCase):
     def setUp(self):
         self.alm = a.Alm(10,10)
     def test_alm_create(self):
@@ -23,5 +26,15 @@ class TestMemLeaks(unittest.TestCase):
         c = self.alm.get_data()
         while True: self.alm.set_data(c)
 
+class TestSuite(unittest.TestSuite):
+    """A unittest.TestSuite class which contains all of the aipy._alm unit tests."""
+
+    def __init__(self):
+        unittest.TestSuite.__init__(self)
+
+        loader = unittest.TestLoader()
+        self.addTests(loader.loadTestsFromTestCase(TestAlm))
+        #self.addTests(loader.loadTestsFromTestCase(TestMemLeaks))
+
 if __name__ == '__main__':
     unittest.main()
